@@ -30,10 +30,12 @@
 #include <fcitx-utils/uthash.h>
 #include <fcitx-config/hotkey.h>
 #include <fcitx-config/xdg.h>
+#include <fcitx/addon.h>
 
 #include "config_widget.h"
 #include "keygrab.h"
 #include "sub_config_widget.h"
+#include "configdesc.h"
 
 #define _(s) gettext(s)
 #define D_(d, x) dgettext (d, x)
@@ -161,6 +163,8 @@ fcitx_config_widget_setup_ui(FcitxConfigWidget *self)
             for (; codesc != NULL;
                     codesc = (FcitxConfigOptionDesc*)codesc->hh.next, i++) {
                 const char *s;
+                FcitxConfigOptionDesc2 *codesc2 =
+                    (FcitxConfigOptionDesc2*)codesc;
                 if (codesc->desc && strlen(codesc->desc) != 0)
                     s = D_(cfdesc->domain, codesc->desc);
                 else
@@ -236,9 +240,22 @@ fcitx_config_widget_setup_ui(FcitxConfigWidget *self)
                 if (inputWidget) {
                     GtkWidget* label = gtk_label_new(s);
                     g_object_set(label, "xalign", 0.0f, NULL);
-                    gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1, GTK_FILL, GTK_SHRINK, 5, 5);
-                    gtk_table_attach(GTK_TABLE(table), inputWidget, 1, 2, i, i + 1, GTK_EXPAND | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 4);
-                    FcitxConfigBindValue(self->gconfig.configFile, cgdesc->groupName, codesc->optionName, NULL, sync_filter, argument);
+                    gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1,
+                                     GTK_FILL, GTK_SHRINK, 5, 5);
+                    gtk_table_attach(GTK_TABLE(table), inputWidget, 1, 2, i,
+                                     i + 1, GTK_EXPAND | GTK_FILL,
+                                     GTK_SHRINK | GTK_FILL, 0, 4);
+                    if (codesc2->longDesc && *codesc2->longDesc) {
+                        const char *tooltip = D_(cfdesc->domain,
+                                                 codesc2->longDesc);
+                        gtk_widget_set_tooltip_text(GTK_WIDGET(label),
+                                                    tooltip);
+                        gtk_widget_set_tooltip_text(GTK_WIDGET(inputWidget),
+                                                    tooltip);
+                    }
+                    FcitxConfigBindValue(self->gconfig.configFile,
+                                         cgdesc->groupName, codesc->optionName,
+                                         NULL, sync_filter, argument);
                 }
             }
         }
@@ -282,8 +299,7 @@ fcitx_config_widget_new(FcitxConfigFileDesc* cfdesc, const gchar* prefix, const
                      "prefix", prefix,
                      "name", name,
                      "subconfig", subconfig,
-                     NULL
-                    );
+                     NULL);
     fcitx_config_widget_setup_ui(widget);
     return widget;
 }
@@ -566,3 +582,35 @@ gboolean fcitx_config_widget_response_cb(GtkDialog *dialog,
     gtk_widget_destroy(GTK_WIDGET(dialog));
     return FALSE;
 }
+
+GtkWidget* fcitx_config_dialog_new(FcitxAddon* addon, GtkWindow* parent)
+{
+    gchar* config_desc_name = g_strdup_printf("%s.desc", addon->name);
+    FcitxConfigFileDesc* cfdesc = get_config_desc(config_desc_name);
+    g_free(config_desc_name);
+    gboolean configurable = (gboolean)(cfdesc != NULL || strlen(addon->subconfig) != 0);
+    if (!configurable) {
+        return NULL;
+    }
+    GtkWidget* dialog = gtk_dialog_new_with_buttons(addon->generalname,
+                        parent,
+                        GTK_DIALOG_MODAL,
+                        GTK_STOCK_OK,
+                        GTK_RESPONSE_OK,
+                        GTK_STOCK_CANCEL,
+                        GTK_RESPONSE_CANCEL,
+                        NULL
+                                                );
+
+    gchar* config_file_name = g_strdup_printf("%s.config", addon->name);
+    FcitxConfigWidget* config_widget = fcitx_config_widget_new(cfdesc, "conf", config_file_name, addon->subconfig);
+    GtkWidget* content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+    gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(config_widget), TRUE, TRUE, 0);
+    g_free(config_file_name);
+    gtk_widget_set_size_request(GTK_WIDGET(config_widget), -1, 400);
+
+    g_signal_connect(dialog, "response",
+                    G_CALLBACK(fcitx_config_widget_response_cb),
+                    config_widget);
+    return dialog;
+}
