@@ -58,7 +58,7 @@ struct _FcitxImWidget {
     GtkWidget* moveupbutton;
     GtkWidget* movedownbutton;
     GtkWidget* configurebutton;
-    GtkWidget* default_layout_button;
+    // GtkWidget* default_layout_button;
     GtkWidget* scrolledwindow;
     GtkWidget* toolbar;
     GtkBuilder* builder;
